import * as colors from "kleur/colors";
import { arch, platform } from "node:os";
import whichPm from "which-pm";
import { resolveConfig } from "../../core/config/index.js";
import { ASTRO_VERSION } from "../../core/constants.js";
import { flagsToAstroInlineConfig } from "../flags.js";
async function printInfo({ flags }) {
  const inlineConfig = flagsToAstroInlineConfig(flags);
  const packageManager = await whichPm(process.cwd());
  let adapter = "Couldn't determine.";
  let integrations = [];
  const MAX_PADDING = 25;
  function printRow(label, value) {
    const padding = MAX_PADDING - label.length;
    console.log(`${colors.bold(label)}` + " ".repeat(padding) + `${colors.green(value)}`);
  }
  try {
    const { userConfig } = await resolveConfig(inlineConfig, "info");
    if (userConfig.adapter?.name) {
      adapter = userConfig.adapter.name;
    }
    if (userConfig.integrations) {
      integrations = (userConfig?.integrations ?? []).filter(Boolean).flat().map((i) => i?.name);
    }
  } catch (_e) {
  }
  console.log();
  const packageManagerName = packageManager?.name ?? "Couldn't determine.";
  printRow("Astro version", `v${ASTRO_VERSION}`);
  printRow("Package manager", packageManagerName);
  printRow("Platform", platform());
  printRow("Architecture", arch());
  printRow("Adapter", adapter);
  let integrationsString = "None or couldn't determine.";
  if (integrations.length > 0) {
    integrationsString = integrations.join(", ");
  }
  printRow("Integrations", integrationsString);
}
export {
  printInfo
};
